.TH ET 1L " 5 Mars 1995 "
.SH NAME
et \- a simple text editor
.SH SYNOPSIS
.B et
.RI [ options ]
.RB [ file1
.RI [ options ]
.RB [ file2
.RI [ options ]]]
.PP
.\"=========================================================================
.SH DESCRIPTION
.B et
is a simple and flexible ASCII text editor.
.B et
was originally designed for MSDOS and is mostly like the editor
of
.IR "Turbo C" " (tm)."
Apart from a few exceptions, most commands of
.B et
behave exactly like those of
.IR "Turbo C" .
.PP
.\"=========================================================================
.SH OPTIONS
Command line options may be specified in any order and before or after
the file name(s). When a same option appears more than once on the
command line, the last one overrides previous ones. Options and file
names should be seperated by spaces, but there should be no space
between an option and its value.
.PP
Valid options are:
.TP
.BI \-c on  |  off
turns on/off support for Chinese characters (based on GB2312 encoding).
.TP
.B \-h
prints a summary of command-line options and environment variables
recognized by
.BR et .
.TP
.BI \-b on  |  off
turns auto backup mode
.I on
or
.IR off .
When auto backup mode is
.IR on ,
a backup copy of the original contents will be created
(.bak file) when the file being edited is saved.
.TP
.BI \-i on | off
turns auto indent mode
.I on
or
.IR off .
.TP
.BI \-r on | off
turns auto carriage-return mode
.I on
or
.IR off .
When auto carriage-return mode is
.IR on ,
a new line character will be automatically inserted when the
line width exceeds a certain limit (currently 72) while inserting
characters.
.TP
.BI \-t on | off
turns tab expansion mode
.I on
or
.IR off .
.TP
.BI \-m filename
loads a macro definition file (see below under the section
.B MACRO DEFINITION FILE
for a description of the macro definition file).
.TP
.B \-d
indicates that the input files are in MSDOS format (for Unix only).
.TP
.BI \-w #
sets the number of ticks (in 10-th second) to wait for completing an escape
sequence. Default value is 0. Setting to a positive value will cause
a short pause each time when the
.B Esc
key is pressed, and this is only necessary when editing on a remote
terminal (for Unix only).
.TP
.B \-l
lists built-in terminal types which may be assigned to
.B ETTERM
environment variable (for Unix only).
.TP
.B \-u
indicates that the input files are in Unix format (for MSDOS only).
.TP
.BI \-pt #
sets foreground color to
.I #
(for MSDOS only).
.TP
.BI \-pb #
sets background color to
.I #
(for MSDOS only).
.PP
When
.B et
starts up, it looks for the file
.BR .et.ini ,
in the user's home directory on Unix systems, or for the file
.B ET.INI
in the same directory where the file
.B ET.EXE
is found on MSDOS. If this file exists,
.B et
loads initial options defined in it. The options are the same as on the
command line, with new line characters treated as spaces.
.PP
.\"=========================================================================
.SH ENVIRONMENT VARIABLES
.B et
recognizes two environment variables
.B ETTICKS
and
.BR ETTERM .
The variable
.B ETTICKS
should be set to an integer value which indicates the number of ticks
(in 10-th second) to wait when completing an escape sequence (see
.B \-w
option in the last section).

.B et
has a set of special built-in terminal types. Built-in terminals
permit to make full use of
.B Alt
keys, keypad keys, etc. A built-in terminal type can be selected by
setting the environment variable
.BR ETTERM .
For example, suppose you are using C shell, then you can add the following
line to the file
.BR ~/.login :

.B setenv ETTERM linux-console

to select the built-in terminal type
.BR linux-console .
A list of valid built-in terminal names can be obtained by typing the command
.BR "et \-l" .
Make sure to select the correct terminal type which matches the one you are
using.

If the variable
.B ETTERM
is not set,
.B et
will first try to find a built-in terminal type which matches the
.B TERM
variable and the machine architecture. If
.B et
fails to find out an entry in its internal terminal capability database,
it will consult
.B termcap
or
.B terminfo
databases to determine the terminal control sequences needed.
.PP
.\"=========================================================================
.SH EDIT COMMAND KEYS
There are two sets of command keys defined in
.BR et .
The first set of command keys is based on function keys, arrow keys, and
.B Alt
keys,  while the second set of command keys consists of combinations of control
keys. Each edit command is provided with at least one command key sequence
in each command key set. This is because the first set of command keys
may not work with certain terminals, while the second set of command keys
should work on any terminals.

In the following subsections,
.B [Larrow]
represents the left arrow key,
.B [Rarrow]
represents the right arrow key,
.B ^[Uarrow]
represents Ctrl+right arrow, and
.B ^QS
represents
.B Ctrl-Q
followed by either
.B Ctrl-S
or
.BR S ,
etc.
.PP
.\"=========================================================================

.SH (1) " Basic cursor movement "
.PP

.TP
.BR [Larrow] , " ^S"
move the cursor one character left.
.TP
.BR [Rarrow] , " ^D"
move the cursor one character right.
.TP
.BR ^[Larrow] , " ^A"
move the cursor one word left.
.TP
.BR ^[Rarrow] , " ^F"
move the cursor one word right.
.TP
.BR [Uarrow] , " ^E"
move the cursor one line up.
.TP
.BR [Darrow] , " ^X"
move the cursor one line down.
.TP
.BR ^[Uarrow] , " ^W"
scroll the screen one one line up.
.TP
.BR ^[Darrow] , " ^Z"
scroll the screen one one line down.
.TP
.BR [PgUp] , " ^R"
move to previous page.
.TP
.BR [PgDn] , " ^C"
move to next page.
.PP
.\"=========================================================================

.SH (2) " Quick cursor movement"
.PP

.TP
.BR [Home] , " ^QS"
move to begin of line.
.TP
.BR [End] , " ^QD"
move to end of line.
.TP
.BR Alt-B , " ^QB"
move to begin of block.
.TP
.BR Alt-K , " ^QK"
move to end of block.
.TP
.BR ^[PgUp] , " ^QR"
move to begin of file.
.TP
.BR ^[PgDn] , " ^QC"
move to end of file.
.TP
.BR ^[Home] , " ^QE"
move to top of screen.
.TP
.BR ^[End] , " ^QX"
move to bottom of screen.
.TP
.BR Alt-G , " ^QG" , " ^OG"
move to specified line number.
.PP
.\"=========================================================================

.SH (3) " Insert and delete"
.PP

.TP
.BR [BackSpace] , " ^H"
delete left character (backspace).
.TP
.BR [Del] , " ^G"
delete the character under the cursor.
.TP
.BR Alt-N , " ^N"
insert one line above.
.TP
.BR Alt-T , " ^T"
delete right word.
.TP
.BR Alt-E , " ^QY"
delete to end of line.
.TP
.BR Alt-J , " ^Y"
delete current line.
.TP
.BR [F6] , " ^QL"
restore last deleted line.
.PP
.\"=========================================================================

.SH (4) " Block operations"
.PP

.TP
.BR [F7] , " ^KB"
mark begin of block.
.TP
.BR [F8] , " ^KK"
mark end of block.
.TP
.BR Alt-M , " ^KT"
mark a word as block.
.TP
.BR Alt-C , " ^KC"
copy block.
.TP
.BR Alt-V , " ^KV"
move block.
.TP
.BR Alt-R , " ^KR"
read block from a file.
.TP
.BR Alt-W , " ^KW"
write block to a file.
.TP
.BR Alt-Y , " ^KY"
delete block.
.TP
.BR Alt-1 , " ^OC"
letters in block to upper case.
.TP
.BR Alt-2 , " ^OM"
letters in block to lower case.
.TP
.BR [F5] , " ^OK"
copy block from another edit buffer.
.PP
.\"=========================================================================

.SH (5) " Edit modes"
.PP

.TP
.BR [Ins] , " ^V"
toggle between insert and replace modes (marked by "Ins" in the status line).
.TP
.BR [F1] , " ^QI" , " ^OI"
toggle auto-indent mode on/off (marked by "Ind" in the status line).
.TP
.BR [F2] , " ^QT" , " ^OT"
toggle tab expansion mode on/off (marked by "T" in the status line).
.TP
.BR [F3] , " ^OB"
toggle auto backup mode on/off (marked by "B" in the status line).
.TP
.BR [F4] , " ^OR"
toggle auto carriage return mode on/off (marked by "R" in the status line).
.TP
.BR Alt-H , " ^KH"
toggle hide/show block.
.PP
.\"=========================================================================

.SH (6) " Miscellaneous commands"
.PP

.TP
.BR Alt-F , " ^QF"
find string.
.TP
.BR Alt-S , " ^QA"
find and replace string.
.TP
.BR Alt-L , " ^L"
repeat last find or replace command.
.TP
.BR n.a. , " ^P"
control character prefix. Any character following
.B ^P
(including control characters) will be inserted into the
text.
.TP
.BR Alt-A , " ^OA"
call macro.
.TP
.BR Alt-Z , " ^OZ"
toggle between displaying only the current edit buffer or the two buffers
simultaneously.
.TP
.BR Alt-X , " ^OX"
toggle the current edit buffer.
.TP
.BR [F10] , " ^KS"
save current edit buffer.
.TP
.BR Alt-9 , " ^OO" , " ^O9"
find the left parenthesis matching the character under the cursor.
.TP
.BR Alt-0 , " ^OP" , " ^O0"
find the right parenthesis matching the character under the cursor.
.TP
.BR [Esc] , " ^U" , " ^KD" , " ^KQ"
invoke the main menu.
.PP
.\"=========================================================================
.SH OPTIONS FOR FIND AND REPLACE COMMANDS
User may specify some options to the
.B Find
and
.B Replace
commands. An option consists of a single letter or a number.
Upper and lower case letters are treated as the same.
Several options can be specified at the same time in any order
with no space between them.
.PP
The valid options are:
.TP
.B W
Search only for entire words.
.TP
.B B
Backward searching.
.TP
.B G
Global searching - find or replace all occurrence of the string.
.TP
.B U
Case insensitive searching.
.TP
.I num
Search for the
.IR num -th
occurrence of the string for the
.B Find
command, or replace the first
.I num
occurrences of the string for the
.B Replace
command.
.TP
.B N
Don't ask for individual confirmations when replacing strings.
.PP
When specifying the string to be searched for,
.B ^A
matches any character (wild card), while
.B ^N
represents the new line character (they should be entered by typing
.B Ctrl-P Ctrl-A
and
.BR "Ctrl-P Ctrl-N" ,
respectively).
.B ^N
can also be used in the replacement string.
.PP
.\"=========================================================================
.SH THE MAIN MENU
The main menu can be invoked by pressing
.B [Esc]
or
.BR Ctrl-U .
To leave the main menu, either press
.B [Esc]
or
.BR Ctrl-U ,
or select the
.B Edit
command of the menu.
.PP
The main menu contains the following commands:
.TP
.B Edit
Leave the main menu and return to the editor.
.TP
.B Save
Save contents of the current edit buffer to disk.
.TP
.B Rename
Change the name of the file associated with the current edit buffer.
.TP
.B New file
Load a new file into the current edit buffer. If the current edit
buffer is changed and not yet saved,
.B et
will ask the user if the current edit buffer should be saved before
loading the new file.
.TP
.B Os shell
On MSDOS system, this command creates an internal shell by executing
.BR COMMAND.COM ,
The user can return back to the editor by typing
.B exit
command at the DOS prompt.

On Unix systems, the editor is stopped. The user should use
.B fg
command to return to the editor.
.TP
.B Quit
Leave the editor. If the edit buffers are changed and not yet
saved,
.B et
will ask the user if the file(s) should be saved before leaving
the editor.
.PP
.\"=========================================================================
.SH MACRO DEFINITION FILE
.B et
allows users to define frequently used sequences of key strokes as macros.
The macro definitions should be placed in a
.I macro definition file
and loaded using the
.B \-m
option.

In a
.IR macro definition file ,
each line defines a macro. A macro consists of a macro name
and a string. The macro names are composed of 0 to 5 characters,
they are used to identify the macros. The macro strings can contain
any characters (including control characters, which permit users
to insert edit commands into a macro). A macro name and its associated
macro string should be seperated by the equal sign "=".

Here are some examples of macro definitions:

 a=\\alpha

 fr=\\frac{}{}^S^S^S

 cent=\\begin{center}^M^M\\end{center}^Q^S^E

where
.B ^S
represents
.B Ctrl-S
(obtained by pressing
.B Ctrl-P Ctrl-S
in the editor), and
.B ^M
represents
.BR Ctrl-M ,
etc.
.PP
To call a macro, type
.B Alt-A
or
.B Ctrl-O Ctrl-A
followed by the macro name followed by
.BR [Enter] .
When a macro is called, its associated macro string is inserted
into the key buffer as if the characters in the macro string were
typed on the keyboard. Note that there is no way to insert
.B ^J
(the new line character) into a macro string on Unix systems, but
this is permitted on MSDOS.
.PP
.\"=========================================================================
.SH DIFFERENCES BETWEEN ET AND THE EDITOR OF TURBO-C
.PP
For those who are familiar with the editor of
.I "Turbo C"
, here are some commands of
.I "Turbo C"
which behave differently in
.BR et :
.TP
.BR "(1)  Ctrl-QL " "(restore current line)"
In
.B et
this command is used to restore the last line deleted by
.B Ctrl-Y
command.
.TP
.BR "(2)  Ctrl-KP " "(print block)"
This command is not implemented in
.BR et .
.TP
.BR "(3)  Ctrl-Q# ", "Ctrl-K# " "(mark and goto positions)"
where
.B #
represents a digit. These commands are not implemented in
.BR et .
.TP
.BR "(4)  Function keys"
The function keys are assigned different meanings in
.BR et .
.PP
.\"=========================================================================
.SH AUTHOR
Lin Bo Zhang,

State Key Labpratory of Scientific and Engineering Computing,

Institute of Computational Mathematics and Scientific/Engineering Computing,

Academia Sinica.

zlb@lsec.cc.ac.cn

.\" end of file
